@@ -13,15 +13,19 @@ source = data.sp500.url
 
 brush = alt.selection(type='interval', encodings=['x'])
 
-upper = alt.Chart(source).mark_area().encode(
-    alt.X('date:T', scale=alt.Scale(domain=brush)),
-    y='price:Q'
+base = alt.Chart(source).mark_area().encode(
+    x = 'date:T',
+    y = 'price:Q'
 ).properties(
     width=600,
     height=200
 )
 
-lower = upper.properties(
+upper = base.encode(
+    alt.X('date:T', scale=alt.Scale(domain=brush))
+)
+
+lower = base.properties(
     height=60
 ).add_selection(brush)
 
