@@ -8,7 +8,7 @@ from .core import (
     update_nested,
     display_traceback,
     SchemaBase,
-    Undefined
+    Undefined,
 )
 from .html import spec_to_html
 from .plugin_registry import PluginRegistry
@@ -16,17 +16,17 @@ from .deprecation import AltairDeprecationWarning
 
 
 __all__ = (
-    'infer_vegalite_type',
-    'infer_encoding_types',
-    'sanitize_dataframe',
-    'spec_to_html',
-    'parse_shorthand',
-    'use_signature',
-    'update_subtraits',
-    'update_nested',
-    'display_traceback',
-    'AltairDeprecationWarning',
-    'SchemaBase',
-    'Undefined',
-    'PluginRegistry'
+    "infer_vegalite_type",
+    "infer_encoding_types",
+    "sanitize_dataframe",
+    "spec_to_html",
+    "parse_shorthand",
+    "use_signature",
+    "update_subtraits",
+    "update_nested",
+    "display_traceback",
+    "AltairDeprecationWarning",
+    "SchemaBase",
+    "Undefined",
+    "PluginRegistry",
 )
