@@ -16,18 +16,19 @@ import m2r
 sys.path.insert(0, abspath(dirname(__file__)))
 from schemapi import codegen  # noqa: E402
 from schemapi.codegen import CodeSnippet  # noqa: E402
-from schemapi.utils import (
+from schemapi.utils import (  # noqa: E402
     get_valid_identifier,
     SchemaInfo,
     indent_arglist,
     resolve_references,
-)  # noqa: E402
+)
 import generate_api_docs  # noqa: E402
 
 # Map of version name to github branch name.
 SCHEMA_VERSION = {
     "vega": {"v5": "v5.10.0"},
-    "vega-lite": {"v3": "v3.4.0", "v4": "v4.8.1"},
+    "vega-lite": {"v3": "v3.4.0", "v4": "v4.17.0"}
+    # "vega-lite": {"v3": "v3.4.0", "v4": "v4.8.1"},
 }
 
 reLink = re.compile(r"(?<=\[)([^\]]+)(?=\]\([^\)]+\))", re.M)
@@ -157,6 +158,19 @@ class ValueChannelMixin(object):
         return super(ValueChannelMixin, copy).to_dict(validate=validate,
                                                       ignore=ignore,
                                                       context=context)
+
+
+class DatumChannelMixin(object):
+    def to_dict(self, validate=True, ignore=(), context=None):
+        context = context or {}
+        datum = getattr(self, 'datum', Undefined)
+        copy = self  # don't copy unless we need to
+        if datum is not Undefined:
+            if isinstance(datum, core.SchemaBase):
+                pass
+        return super(DatumChannelMixin, copy).to_dict(validate=validate,
+                                                      ignore=ignore,
+                                                      context=context)
 """
 
 
@@ -186,6 +200,18 @@ class ValueSchemaGenerator(SchemaGenerator):
     )
 
 
+class DatumSchemaGenerator(SchemaGenerator):
+    schema_class_template = textwrap.dedent(
+        '''
+    class {classname}(DatumChannelMixin, core.{basename}):
+        """{docstring}"""
+        _class_is_valid_at_instantiation = False
+        _encoding_name = "{encodingname}"
+        {init_code}
+    '''
+    )
+
+
 HEADER = """\
 # The contents of this file are automatically written by
 # tools/generate_schema_wrapper.py. Do not modify directly.
@@ -240,6 +266,36 @@ def copy_schemapi_util():
             dest.writelines(source.readlines())
 
 
+def recursive_dict_update(schema, root, def_dict):
+    if "$ref" in schema:
+        next_schema = resolve_references(schema, root)
+        if "properties" in next_schema:
+            definition = schema["$ref"]
+            properties = next_schema["properties"]
+            for k in def_dict.keys():
+                if k in properties:
+                    def_dict[k] = definition
+        else:
+            recursive_dict_update(next_schema, root, def_dict)
+    elif "anyOf" in schema:
+        for sub_schema in schema["anyOf"]:
+            recursive_dict_update(sub_schema, root, def_dict)
+
+
+def get_field_datum_value_defs(propschema, root):
+    def_dict = {k: None for k in ("field", "datum", "value")}
+    schema = propschema.schema
+    if propschema.is_reference() and "properties" in schema:
+        if "field" in schema["properties"]:
+            def_dict["field"] = propschema.ref
+        else:
+            raise ValueError("Unexpected schema structure")
+    else:
+        recursive_dict_update(schema, root, def_dict)
+
+    return {i: j for i, j in def_dict.items() if j}
+
+
 def toposort(graph):
     """Topological sort of a directed acyclic graph.
 
@@ -390,22 +446,16 @@ def generate_vegalite_channel_wrappers(schemafile, version, imports=None):
     encoding = SchemaInfo(schema["definitions"][encoding_def], rootschema=schema)
 
     for prop, propschema in encoding.properties.items():
-        if propschema.is_reference():
-            definitions = [propschema.ref]
-        elif propschema.is_anyOf():
-            definitions = [s.ref for s in propschema.anyOf if s.is_reference()]
-        else:
-            raise ValueError("either $ref or anyOf expected")
-        for definition in definitions:
-            defschema = {"$ref": definition}
-            basename = definition.split("/")[-1]
-            classname = prop[0].upper() + prop[1:]
+        def_dict = get_field_datum_value_defs(propschema, schema)
 
-            if "Value" in basename:
-                Generator = ValueSchemaGenerator
-                classname += "Value"
-                nodefault = ["value"]
-            else:
+        for encoding_spec, definition in def_dict.items():
+            classname = prop[0].upper() + prop[1:]
+            basename = definition.split("/")[-1]
+            basename = get_valid_identifier(basename)
+
+            defschema = {"$ref": definition}
+
+            if encoding_spec == "field":
                 Generator = FieldSchemaGenerator
                 nodefault = []
                 defschema = copy.deepcopy(resolve_references(defschema, schema))
@@ -418,6 +468,16 @@ def generate_vegalite_channel_wrappers(schemafile, version, imports=None):
                 }
                 defschema["required"] = ["shorthand"]
 
+            elif encoding_spec == "datum":
+                Generator = DatumSchemaGenerator
+                classname += "Datum"
+                nodefault = ["datum"]
+
+            elif encoding_spec == "value":
+                Generator = ValueSchemaGenerator
+                classname += "Value"
+                nodefault = ["value"]
+
             gen = Generator(
                 classname=classname,
                 basename=basename,
@@ -458,7 +518,10 @@ def generate_vegalite_mark_mixin(schemafile, markdefs):
     ]
 
     for mark_enum, mark_def in markdefs.items():
-        marks = schema["definitions"][mark_enum]["enum"]
+        if "enum" in schema["definitions"][mark_enum]:
+            marks = schema["definitions"][mark_enum]["enum"]
+        else:
+            marks = [schema["definitions"][mark_enum]["const"]]
         info = SchemaInfo({"$ref": "#/definitions/" + mark_def}, rootschema=schema)
 
         # adapted from SchemaInfo.init_code
