@@ -148,6 +148,7 @@ class SchemaBase(object):
     _schema = None
     _rootschema = None
     _class_is_valid_at_instantiation = True
+    _validator = jsonschema.Draft7Validator
 
     def __init__(self, *args, **kwds):
         # Two valid options for initialization, which should be handled by
@@ -437,7 +438,9 @@ class SchemaBase(object):
         if schema is None:
             schema = cls._schema
         resolver = jsonschema.RefResolver.from_schema(cls._rootschema or cls._schema)
-        return jsonschema.validate(instance, schema, resolver=resolver)
+        return jsonschema.validate(
+            instance, schema, cls=cls._validator, resolver=resolver
+        )
 
     @classmethod
     def resolve_references(cls, schema=None):
@@ -462,6 +465,10 @@ class SchemaBase(object):
         return list(self._kwds.keys())
 
 
+def _passthrough(*args, **kwds):
+    return args[0] if args else kwds
+
+
 class _FromDict(object):
     """Class used to construct SchemaBase class hierarchies from a dict
 
@@ -516,7 +523,9 @@ class _FromDict(object):
 
             return hash(_freeze(schema))
 
-    def from_dict(self, dct, cls=None, schema=None, rootschema=None):
+    def from_dict(
+        self, dct, cls=None, schema=None, rootschema=None, default_class=_passthrough
+    ):
         """Construct an object from a dict representation"""
         if (schema is None) == (cls is None):
             raise ValueError("Must provide either cls or schema, but not both.")
@@ -525,9 +534,6 @@ class _FromDict(object):
             rootschema = rootschema or cls._rootschema
         rootschema = rootschema or schema
 
-        def _passthrough(*args, **kwds):
-            return args[0] if args else kwds
-
         if isinstance(dct, SchemaBase):
             return dct
 
@@ -536,7 +542,10 @@ class _FromDict(object):
             # Our class dict is constructed breadth-first from top to bottom,
             # so the first class that matches is the most general match.
             matches = self.class_dict[self.hash_schema(schema)]
-            cls = matches[0] if matches else _passthrough
+            if matches:
+                cls = matches[0]
+            else:
+                cls = default_class
         schema = _resolve_references(schema, rootschema)
 
         if "anyOf" in schema or "oneOf" in schema:
@@ -549,7 +558,10 @@ class _FromDict(object):
                     continue
                 else:
                     return self.from_dict(
-                        dct, schema=possible_schema, rootschema=rootschema,
+                        dct,
+                        schema=possible_schema,
+                        rootschema=rootschema,
+                        default_class=cls,
                     )
 
         if isinstance(dct, dict):
